@@ -1,4 +1,5 @@
 package Pod::ProjectDocs;
+$Pod::ProjectDocs::VERSION = '0.41';
 use strict;
 use warnings;
 
@@ -16,8 +17,6 @@ use Pod::ProjectDocs::IndexPage;
 
 __PACKAGE__->mk_accessors(qw/managers components config/);
 
-our $VERSION = '0.40';
-
 sub new {
     my $class = shift;
     my $self  = bless { }, $class;
@@ -163,7 +162,9 @@ sub get_managers_json {
             push @$records, $record;
         }
     }
-    return $js->encode($records);
+    # Use "canonical" to generate stable structures that can be added
+    #   to version control systems without changing all the time.
+    return $js->canonical()->encode($records);
 }
 
 sub _croak {
