@@ -1,6 +1,8 @@
 package Pod::ProjectDocs::Doc;
+$Pod::ProjectDocs::Doc::VERSION = '0.41';
 use strict;
 use warnings;
+
 use base qw/Pod::ProjectDocs::File/;
 use File::Basename;
 use File::Spec;
@@ -29,7 +31,12 @@ sub _set_relpath {
     $self->_check_dir($reldir, File::Spec->catdir($outroot, "src"));
     my $relpath = File::Spec->catdir($reldir, $name);
     $relpath =~ s:\\:/:g if $^O eq 'MSWin32';
-    $self->name( join "-", File::Spec->splitdir($relpath) );
+    if (lc $suffix eq 'pm') {
+        $self->name( join "::", File::Spec->splitdir($relpath) );
+    }
+    else {
+        $self->name( join "-", File::Spec->splitdir($relpath) );
+    }
     $self->relpath($relpath.".".$suffix.".html");
 }
 
@@ -94,5 +101,3 @@ __DATA__
 <div>
 <a href="[% src | relpath %]">Source</a>
 </div>
-
-
