@@ -1,9 +1,11 @@
 package Pod::ProjectDocs::DocManager;
+$Pod::ProjectDocs::DocManager::VERSION = '0.41';
 use strict;
 use warnings;
-use base qw/Class::Accessor::Fast/;
 
+use base qw/Class::Accessor::Fast/;
 use File::Find;
+use IO::File;
 use Pod::ProjectDocs::Doc;
 
 __PACKAGE__->mk_accessors(qw/
@@ -61,6 +63,11 @@ sub _find_files {
                         last;
                     }
                 }
+
+                # check if there is actually any POD inside, skip otherwise
+                my $content = join('', IO::File->new( $File::Find::name, 'r' )->getlines());
+                $matched = 1 if $content !~ m{^=(head1|head2|item|cut)}ismxg;
+
                 unless ($matched) {
                     push @{ $self->docs },
                       Pod::ProjectDocs::Doc->new(
@@ -105,7 +112,9 @@ sub _croak {
 }
 
 package Pod::ProjectDocs::DocManager::Iterator;
+$Pod::ProjectDocs::DocManager::Iterator::VERSION = '0.41';
 use base qw/Class::Accessor::Fast/;
+
 __PACKAGE__->mk_accessors(qw/manager index/);
 
 sub new {
@@ -140,4 +149,3 @@ sub reset {
 
 1;
 __END__
-
