@@ -1,6 +1,8 @@
 package Pod::ProjectDocs::Parser;
+$Pod::ProjectDocs::Parser::VERSION = '0.41';
 use strict;
 use warnings;
+
 use base qw/Pod::Parser Class::Accessor::Fast Class::Data::Inheritable/;
 use Pod::ParseUtils;
 use URI::Escape;
@@ -8,7 +10,6 @@ use File::Spec;
 use File::Basename;
 use Pod::ProjectDocs::Template;
 
-
 our $METHOD_REGEXP ||= qr/^(\w+).*/;
 
 BEGIN {
@@ -208,6 +209,9 @@ sub _addCommand {
         return;
     }
 
+    # skip if we are actually in a "dataSection" (between =begin and =end)
+    return if @{$self->{dataSections}} && ($command ne 'begin' && $command ne 'end');
+
     for ($command) {
         /^head1/ && do {
             $anchor = $self->_addSection( 'head1', $paragraph );
